@@ -16,7 +16,13 @@ function _omb_theme_PROMPT_COMMAND {
   local ps_path="${_omb_prompt_green}\w${_omb_prompt_normal}"
   local ps_user_mark="${_omb_prompt_red}λ${_omb_prompt_normal}"
 
-  PS1="$ps_username in $ps_path$(_omb_theme_half_way_prompt_scm) $ps_user_mark "
+  local python_venv
+  _omb_prompt_get_python_venv
+
+  PS1="$ps_username in $python_venv$ps_path$(_omb_theme_half_way_prompt_scm) $ps_user_mark "
 }
 
+OMB_PROMPT_SHOW_PYTHON_VENV=${OMB_PROMPT_SHOW_PYTHON_VENV:-false}
+OMB_PROMPT_VIRTUALENV_FORMAT="${_omb_prompt_olive}(%s)${_omb_prompt_reset_color} "
+
 _omb_util_add_prompt_command _omb_theme_PROMPT_COMMAND
